@@ -1,8 +1,7 @@
 /* amp.cpp
 
    Computer Music Toolkit - a library of LADSPA plugins. Copyright (C)
-   2000-2002 Richard W.E. Furse. The author may be contacted at
-   richard@muse.demon.co.uk.
+   2000-2002 Richard W.E. Furse.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public Licence as
