@@ -4,8 +4,7 @@
    Copyright (c) 2001 David A. Bartold
 
    Computer Music Toolkit - a library of LADSPA plugins. Copyright (C)
-   2000 Richard W.E. Furse. The author may be contacted at
-   richard@muse.demon.co.uk.
+   2000 Richard W.E. Furse.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public Licence as
@@ -277,8 +276,6 @@ class LoFi : public CMT_PluginInstance {
   BandwidthLimit *bandwidth_l;
   BandwidthLimit *bandwidth_r;
 
-  int         last_trigger;
-
 public:
   LoFi(const LADSPA_Descriptor *,
        unsigned long s_rate)
