@@ -6,8 +6,7 @@
 
    Part of the Computer Music Toolkit - a library of LADSPA plugins. 
    The Computer Music Toolkit is Copyright (C) 2000-2002 
-   Richard W.E. Furse. The author may be contacted at
-   richard@muse.demon.co.uk.
+   Richard W.E. Furse.
 
    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public Licence as
